@@ -7,6 +7,7 @@ Interface for filesystem access
 import os
 from shutil import copyfile
 from cooker import settings
+from cooker.util import alert
 
 class FileSystem():
     """
@@ -23,9 +24,8 @@ class FileSystem():
         given contents.
 
         """
-        fptr = open(name, 'w')
-        fptr.write(contents)
-        fptr.close()
+        with open(name, 'w') as fptr:
+            fptr.write(contents.strip() + '\n')
 
     @classmethod
     def make_structure(cls, name='test', inp='', out='', path='.'):
@@ -39,16 +39,25 @@ class FileSystem():
 
         # Create destination directory
         dest_dir = '%s/%s' % (path, name)
-        os.mkdir(dest_dir, 0755)
+        try:
+            os.mkdir(dest_dir, 0755)
+        except OSError:
+            resp = raw_input('Problem directory exists. Overwrite (y/n) ? ')
+            if resp == 'n':
+                alert('Exiting on user cancel.')
 
         # Make files
-        files = { 'input': inp, 'output': out, 'test': '' }
+        files = { 'input': inp, 'output': out}
 
         for k in files:
             dest = '%s/%s.txt' % (dest_dir, k)
             cls.create_file(dest, files.get(k))
 
-        src = '%s/template.%s' % (settings.TEMPLATES_DIR,
+        src = '%s/template.%s' % (settings.TEMPLATES,
                                     settings.LANG)
         dest = '%s/main.%s' % (dest_dir, settings.LANG)
-        copyfile(src, dest)
+        try:
+            copyfile(src, dest)
+        except IOError:
+            # destination not writable
+            alert('Unable to write to copy the template file.')
