@@ -4,8 +4,8 @@ sites
 Interface for accessing problems from different sites
 
 """
-import urllib
-import exceptions
+import urllib2
+from cooker.util import alert
 from cooker.parser import HTMLTagsParser
 
 class Site():
@@ -37,15 +37,16 @@ class Site():
         return { 'name': title,
                  'path': kwargs.get('path', '.'),
                  'inp': inp,
-                 'out': out }
+                 'out': out
+                }
 
 
     @classmethod
     def create_url(cls, *args, **kwargs):
         """Constructs the url for given problem and contest"""
         if args or kwargs:
-            raise exceptions.NotImplementedError
-        raise exceptions.ValueError
+            raise NotImplementedError
+        raise ValueError
 
 
     @classmethod
@@ -54,8 +55,16 @@ class Site():
 
         """
         if parsed_content:
-            raise exceptions.NotImplementedError
-        raise exceptions.ValueError
+            raise NotImplementedError
+        raise ValueError
+
+
+    @classmethod
+    def submit(cls, *args, **kwargs):
+        """Abstract method for submitting a problem
+
+        """
+        raise NotImplementedError
 
 
     @classmethod
@@ -67,13 +76,16 @@ class Site():
         """
         # Get a file-like object for the url
         if not url:
-            raise exceptions.ValueError
+            raise ValueError
 
-        resp = urllib.urlopen(url)
-        html = resp.read()
-        resp.close()
+        try:
+            resp = urllib2.urlopen(url)
+            return resp.read()
+        except urllib2.URLError:
+            # Raise a custom error
+            alert('Unable to connect to the internet.')
 
-        return html
+        return ''
 
 
 class CodeChef(Site):
@@ -123,3 +135,8 @@ class CodeChef(Site):
         base = "http://www.codechef.com"
 
         return "%s/%sproblems/%s" % (base, contest, problem)
+
+
+    def submit(self, *args, **kwargs):
+        """Submit a problem to CodeChef"""
+        raise NotImplementedError
